==> kubernetes-model-scheduling-5.9.0-sources.jar: io/fabric8/kubernetes/api/model/scheduling/v1/PriorityClassListBuilder.java <==
package io.fabric8.kubernetes.api.model.scheduling.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;
public class PriorityClassListBuilder extends io.fabric8.kubernetes.api.model.scheduling.v1.PriorityClassListFluentImpl<io.fabric8.kubernetes.api.model.scheduling.v1.PriorityClassListBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.kubernetes.api.model.scheduling.v1.PriorityClassList,io.fabric8.kubernetes.api.model.scheduling.v1.PriorityClassListBuilder>{
  public PriorityClassListBuilder() {
    this(false);
  }
  public PriorityClassListBuilder(java.lang.Boolean validationEnabled) {
    this(new PriorityClassList(), validationEnabled);
  }
  public PriorityClassListBuilder(io.fabric8.kubernetes.api.model.scheduling.v1.PriorityClassListFluent<?> fluent) {
    this(fluent, false);
  }
  public PriorityClassListBuilder(io.fabric8.kubernetes.api.model.scheduling.v1.PriorityClassListFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new PriorityClassList(), validationEnabled);
  }
  public PriorityClassListBuilder(io.fabric8.kubernetes.api.model.scheduling.v1.PriorityClassListFluent<?> fluent,io.fabric8.kubernetes.api.model.scheduling.v1.PriorityClassList instance) {
    this(fluent, instance, false);
  }
  public PriorityClassListBuilder(io.fabric8.kubernetes.api.model.scheduling.v1.PriorityClassListFluent<?> fluent,io.fabric8.kubernetes.api.model.scheduling.v1.PriorityClassList instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withApiVersion(instance.getApiVersion()); 
    fluent.withItems(instance.getItems()); 
    fluent.withKind(instance.getKind()); 
    fluent.withMetadata(instance.getMetadata()); 
    this.validationEnabled = validationEnabled; 
  }
  public PriorityClassListBuilder(io.fabric8.kubernetes.api.model.scheduling.v1.PriorityClassList instance) {
    this(instance,false);
  }
  public PriorityClassListBuilder(io.fabric8.kubernetes.api.model.scheduling.v1.PriorityClassList instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withApiVersion(instance.getApiVersion()); 
    this.withItems(instance.getItems()); 
    this.withKind(instance.getKind()); 
    this.withMetadata(instance.getMetadata()); 
    this.validationEnabled = validationEnabled; 
  }
  io.fabric8.kubernetes.api.model.scheduling.v1.PriorityClassListFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public io.fabric8.kubernetes.api.model.scheduling.v1.PriorityClassList build() {
    PriorityClassList buildable = new PriorityClassList(fluent.getApiVersion(),fluent.getItems(),fluent.getKind(),fluent.getMetadata());
    return buildable;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    PriorityClassListBuilder that = (PriorityClassListBuilder) o;
    if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

    if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
  }
  
}

==> kubernetes-model-scheduling-5.12.1-sources.jar: io/fabric8/kubernetes/api/model/scheduling/v1/PriorityClassListBuilder.java <==
package io.fabric8.kubernetes.api.model.scheduling.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;
public class PriorityClassListBuilder extends io.fabric8.kubernetes.api.model.scheduling.v1.PriorityClassListFluentImpl<io.fabric8.kubernetes.api.model.scheduling.v1.PriorityClassListBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.kubernetes.api.model.scheduling.v1.PriorityClassList,io.fabric8.kubernetes.api.model.scheduling.v1.PriorityClassListBuilder>{
  public PriorityClassListBuilder() {
    this(false);
  }
  public PriorityClassListBuilder(java.lang.Boolean validationEnabled) {
    this(new PriorityClassList(), validationEnabled);
  }
  public PriorityClassListBuilder(io.fabric8.kubernetes.api.model.scheduling.v1.PriorityClassListFluent<?> fluent) {
    this(fluent, false);
  }
  public PriorityClassListBuilder(io.fabric8.kubernetes.api.model.scheduling.v1.PriorityClassListFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new PriorityClassList(), validationEnabled);
  }
  public PriorityClassListBuilder(io.fabric8.kubernetes.api.model.scheduling.v1.PriorityClassListFluent<?> fluent,io.fabric8.kubernetes.api.model.scheduling.v1.PriorityClassList instance) {
    this(fluent, instance, false);
  }
  public PriorityClassListBuilder(io.fabric8.kubernetes.api.model.scheduling.v1.PriorityClassListFluent<?> fluent,io.fabric8.kubernetes.api.model.scheduling.v1.PriorityClassList instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withApiVersion(instance.getApiVersion()); 
    fluent.withItems(instance.getItems()); 
    fluent.withKind(instance.getKind()); 
    fluent.withMetadata(instance.getMetadata()); 
    fluent.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  public PriorityClassListBuilder(io.fabric8.kubernetes.api.model.scheduling.v1.PriorityClassList instance) {
    this(instance,false);
  }
  public PriorityClassListBuilder(io.fabric8.kubernetes.api.model.scheduling.v1.PriorityClassList instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withApiVersion(instance.getApiVersion()); 
    this.withItems(instance.getItems()); 
    this.withKind(instance.getKind()); 
    this.withMetadata(instance.getMetadata()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  io.fabric8.kubernetes.api.model.scheduling.v1.PriorityClassListFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public io.fabric8.kubernetes.api.model.scheduling.v1.PriorityClassList build() {
    PriorityClassList buildable = new PriorityClassList(fluent.getApiVersion(),fluent.getItems(),fluent.getKind(),fluent.getMetadata());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    PriorityClassListBuilder that = (PriorityClassListBuilder) o;
    if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

    if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
  }
  
}
